@@ -3,7 +3,7 @@
  * @brief Implementation of the RobTk-based LV2 GUI for the QMidiArp Seq plugin.
  *
  *
- *      Copyright 2009 - 2023 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2026 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      The structure as well as some lines of code and functions were 
  *      taken from sisco lv2 by Robin Garaeus: https://github.com/x42/sisco.lv2 
@@ -222,7 +222,19 @@ static bool update_range_in1 (RobWidget *widget, void* data)
 static bool update_transport (RobWidget *widget, void* data)
 {
     QMidiArpArpUI* ui = (QMidiArpArpUI*) data;
-    updateParam(ui, TRANSPORT_MODE, robtk_cbtn_get_active(ui->btn_transport));
+    bool act = robtk_cbtn_get_active(ui->btn_transport);
+    if (act) {
+      robtk_cbtn_set_active(ui->btn_tempo_mode, true);
+    }
+    robtk_cbtn_set_sensitive(ui->btn_tempo_mode, !act);
+    updateParam(ui, TRANSPORT_MODE, act);
+    return TRUE;
+}
+
+static bool update_tempo_mode (RobWidget *widget, void* data)
+{
+    QMidiArpArpUI* ui = (QMidiArpArpUI*) data;
+    updateParam(ui, TEMPO_MODE, robtk_cbtn_get_active(ui->btn_tempo_mode));
     return TRUE;
 }
 
@@ -476,6 +488,69 @@ void updatePattern(LV2UI_Handle handle, bool send)
     queue_draw(ui->darea);
 }
 
+static bool update_presets (RobWidget *widget, void* data)
+{
+    QMidiArpArpUI* ui = (QMidiArpArpUI*) data;
+    ui->pattern[0]='\0';
+    int index = robtk_select_get_item(ui->sel_presets);
+    strncat(ui->pattern, ui->patternPresets[index], 256);
+    updatePattern(ui, true);
+    return TRUE;
+}
+
+void loadPatternPresets(LV2_Handle handle)
+{
+  QMidiArpArpUI* ui = (QMidiArpArpUI*) handle;
+  
+  FILE * fp;
+  char * line = NULL;
+  size_t len = 0;
+  ssize_t read;
+  char qmarcpath[256];  
+  qmarcpath[0] = '\0';
+  
+  strncat(qmarcpath, getenv("HOME"), 128);
+  strncat(qmarcpath, "/.qmidiarprc", 32);
+  
+  fp = fopen(qmarcpath, "r");
+  if (fp == NULL) {
+    printf("qmidiarprc file: %s\n", qmarcpath);
+    printf("Could not read the pattern presets from the \n .qmidiarprc resource file.\n");
+    printf("To create this file please just run the qmidiarp main application once.\n");
+    return;
+  }
+  char type[32];
+  int i = 0;
+  bool skip_firstline = true;
+  while ((read = getline(&line, &len, fp)) != -1 && i < MAXNPATTERNS) {
+    if (line[0] == '#') {
+      char * sp = strtok(line, "%");
+      if (sp == NULL) continue;
+      type[0] = '\0';
+      strncat(type, sp, 16);
+      if (strcmp(type, "#Pattern")) continue;
+      if (skip_firstline) {
+        skip_firstline = false;
+        continue;
+      }
+      sp = strtok(NULL, "%");
+      if (sp == NULL || strlen(sp) == 0) continue;
+      ui->presetNames[i][0] = '\0';
+      strncat(ui->presetNames[i], sp, 64);
+      sp = strtok(NULL, "%");
+      if (sp == NULL || strlen(sp) == 0) continue;
+      ui->patternPresets[i][0] = '\0';
+      strncat(ui->patternPresets[i], sp, PATTERNBUFSIZE);
+      i++;
+    }
+  }
+  ui->n_presets = i;
+  
+  fclose(fp);
+  if (line)
+      free(line);
+}
+
 /*
 static void update_mouse(RobWidget* handle) {  
   QMidiArpArpUI* ui = (QMidiArpArpUI*) GET_HANDLE(handle);
@@ -687,7 +762,7 @@ static bool expose_event(RobWidget* handle, cairo_t* cr, cairo_rectangle_t *ev)
         sprintf(int_str, "%d", l1+1);
         render_text(cr, int_str, ui->font[1], 
                 ofs + x + tx_w / 2, 
-                ARPSCR_VMARG - tx_h / 2, 0, 1, color_txt2);
+                ARPSCR_VMARG - tx_h / 2 - 2, 0, 1, color_txt2);
 
         // Beat divisor separators
         cairo_set_source_rgba(cr, 40./256, 100./256, 40./256, 1);
@@ -714,7 +789,7 @@ static bool expose_event(RobWidget* handle, cairo_t* cr, cairo_rectangle_t *ev)
       char int_str[20];
       sprintf(int_str, "%d", noctaves - l1 + ui->minOctave - 1);
       render_text(cr, int_str, ui->font[1], 
-            ARPSCR_HMARG / 2 - 3 + tx_w / 2, 
+            ARPSCR_HMARG / 2 + tx_w / 2, 
             yscale * (l1 + 0.5) / noctaves + ARPSCR_VMARG, 0, 1, color_txt2);
     }
   }
@@ -869,7 +944,7 @@ static bool expose_event(RobWidget* handle, cairo_t* cr, cairo_rectangle_t *ev)
   get_text_geometry(ui->pattern, ui->font[2], &tx_w, &tx_h);
   render_text(cr, ui->pattern, ui->font[2], 
       ARPSCR_HMARG + tx_w, 
-      h - tx_h / 2 + 5, 0, 1, color_txt2);
+      h + 8, 0, 1, color_txt2);
 
   cairo_restore(cr);
   
@@ -965,6 +1040,8 @@ static void in_out_box_new(QMidiArpArpUI* ui)
   robtk_cbtn_set_callback(ui->btn_trigkbd, update_trigkbd, ui);
   robtk_cbtn_set_callback(ui->btn_triglegato, update_triglegato, ui);
 
+  robtk_cbtn_set_active(ui->btn_trigkbd, true);
+
   // ChannelIn selectbox (combobox)
 
   ui->lbl_ch_in = robtk_lbl_new("Ch");
@@ -1046,13 +1123,21 @@ static void in_out_box_new(QMidiArpArpUI* ui)
 
 // Transport controls
 
-  // Host / Internal transport
+  // Internal / Host transport
   ui->btn_transport = robtk_cbtn_new("Host transport", GBT_LED_LEFT, false);
   robtk_cbtn_set_color_on(ui->btn_transport, .2, .8, .5);
   robtk_cbtn_set_color_off(ui->btn_transport, .1, .1, .3);
   robtk_cbtn_set_callback(ui->btn_transport, update_transport, ui);
 
-  robtk_cbtn_set_active(ui->btn_transport, true);
+  
+  // Internal / Host tempo
+  ui->btn_tempo_mode = robtk_cbtn_new("Tempo from host", GBT_LED_LEFT, false);
+  robtk_cbtn_set_color_on(ui->btn_tempo_mode, .2, .8, .5);
+  robtk_cbtn_set_color_off(ui->btn_tempo_mode, .1, .1, .3);
+  robtk_cbtn_set_callback(ui->btn_tempo_mode, update_tempo_mode, ui);
+
+  robtk_cbtn_set_active(ui->btn_tempo_mode, true);
+  robtk_cbtn_set_active(ui->btn_transport, false);
   
   ui->lbl_tempo = robtk_lbl_new("Tempo");
   ui->spb_tempo = robtk_spin_new(5, 200, 1);
@@ -1101,6 +1186,8 @@ static void in_out_box_new(QMidiArpArpUI* ui)
   // Transport
   TBLADD(robtk_cbtn_widget(ui->btn_transport), 0, 2, row, row+1);
   row++;
+  TBLADD(robtk_cbtn_widget(ui->btn_tempo_mode), 0, 2, row, row+1);
+  row++;
   TBLADD(robtk_lbl_widget(ui->lbl_tempo), 0, 1, row, row+1);
   TBLADD(robtk_spin_widget(ui->spb_tempo), 1, 2, row, row+1);
   row++;
@@ -1136,8 +1223,16 @@ static RobWidget * toplevel(QMidiArpArpUI* ui, void * const top)
   //ui->lbl_pattern_text->min_width_scaled = 300;
   //ui->lbl_pattern_text->w_width = 300;
   
+  ui->lbl_presets = robtk_lbl_new("Preset");
+  ui->sel_presets = robtk_select_new();
+  for (int i = 0; i < ui->n_presets; i++) {
+    robtk_select_add_item(ui->sel_presets, i, ui->presetNames[i]);
+  }
+  robtk_select_set_item(ui->sel_presets, 2);
+  robtk_select_set_default_item(ui->sel_presets, 2);
+  robtk_select_set_callback(ui->sel_presets, update_presets, ui);
+  
   ui->lbl_repeat_mode = robtk_lbl_new("Repeat");
-
   ui->sel_repeat_mode = robtk_select_new();
   robtk_select_add_item(ui->sel_repeat_mode, 0, "Static");
   robtk_select_add_item(ui->sel_repeat_mode, 1, "Up");
@@ -1165,7 +1260,7 @@ static RobWidget * toplevel(QMidiArpArpUI* ui, void * const top)
   robtk_cbtn_set_callback(ui->btn_latch, update_latch, ui);
   
   // Octave mode/high/low selectboxes (comboboxes)
-  ui->lbl_oct_mode = robtk_lbl_new("Octave Mode and Range");
+  ui->lbl_oct_mode = robtk_lbl_new("Octave Mode");
   
   ui->sel_oct_mode = robtk_select_new();
   robtk_select_add_item(ui->sel_oct_mode, 0, "Static");
@@ -1249,7 +1344,7 @@ static RobWidget * toplevel(QMidiArpArpUI* ui, void * const top)
 
   /* Repeat and octave mode */
 
-  ui->ctable_wave = rob_table_new(/*rows*/3, /*cols*/ 14, FALSE);
+  ui->ctable_wave = rob_table_new(/*rows*/4, /*cols*/ 14, FALSE);
 
 #define TBLWAVEADD(WIDGET, X0, X1, Y0, Y1) \
   rob_table_attach(ui->ctable_wave, WIDGET, X0, X1, Y0, Y1, 0, 0, RTK_EXANDF, RTK_EXANDF)
@@ -1258,8 +1353,11 @@ static RobWidget * toplevel(QMidiArpArpUI* ui, void * const top)
   rob_table_attach(ui->ctable_wave, WIDGET, X0, X1, Y0, Y1, 0, 0, XX, XY)
 
   int row = 0;
+  TBLWAVEADD(robtk_lbl_widget(ui->lbl_presets), 0, 2, row, row+1);
+  TBLWAVEADD(robtk_select_widget(ui->sel_presets), 3, 7, row, row+1);
+  row++;
   TBLWAVEADD(robtk_lbl_widget(ui->lbl_repeat_mode), 6, 7, row, row+1);
-  TBLWAVEADD(robtk_lbl_widget(ui->lbl_oct_mode), 8, 11, row, row+1);
+  TBLWAVEADD(robtk_lbl_widget(ui->lbl_oct_mode), 8, 9, row, row+1);
   row++;
   TBLWAVEADD(robtk_cbtn_widget(ui->btn_mute), 0, 2, row, row+1);
   TBLWAVEADD(robtk_cbtn_widget(ui->btn_defer), 3, 4, row, row+1);
@@ -1349,12 +1447,19 @@ instantiate(
   ui->patternLen = 0;
   
 /* Default pattern */
-  ui->pattern = (char *) malloc(PATTERNBUFSIZE);
+  ui->patternPresets[0][0] = '\0';
+  strncat(ui->patternPresets[0], ">>0", PATTERNBUFSIZE);
+  ui->patternLen = strlen(ui->patternPresets[0]);
+  
+  ui->presetNames[0][0] = '\0';
+  strncat(ui->presetNames[0], "Simple 16", 32 - 1);
+  ui->n_presets = 1;
+
+  loadPatternPresets(ui);
+  
+  ui->pattern = (char *) malloc(PATTERNBUFSIZE + 2);
   ui->pattern[0] = '\0';
-  strncat(ui->pattern, ">>0", PATTERNBUFSIZE - 1);
-  ui->patternLen = strlen(ui->pattern);
-  
-  
+
   ui->currentIndex = 0;
   ui->isMuted = false;
   
@@ -1399,7 +1504,7 @@ instantiate(
 
   /* On Screen Display -- annotations */
   ui->font[0] = pango_font_description_from_string("Mono 9");
-  ui->font[1] = pango_font_description_from_string("Sans 10");
+  ui->font[1] = pango_font_description_from_string("Sans 9");
   ui->font[2] = pango_font_description_from_string("Sans 8px");
   ui->font[3] = pango_font_description_from_string("Mono 8");
 
@@ -1424,7 +1529,7 @@ instantiate(
   ui_enable(ui);
   
   robwidget_hide(ui->ctable_notefilter, FALSE);
-
+  
   return ui;
 }
 
@@ -1461,6 +1566,7 @@ in_out_box_destroy(QMidiArpArpUI *ui)
   robtk_lbl_destroy(ui->lbl_ch_in);
   robtk_lbl_destroy(ui->lbl_ch_out);
 
+  robtk_cbtn_destroy(ui->btn_tempo_mode);
   robtk_cbtn_destroy(ui->btn_transport);
   robtk_spin_destroy(ui->spb_tempo);
   robtk_lbl_destroy(ui->lbl_tempo);
@@ -1491,7 +1597,9 @@ cleanup(LV2UI_Handle handle)
   
   robtk_lbl_destroy(ui->lbl_oct_mode);
   robtk_lbl_destroy(ui->lbl_repeat_mode);
+  robtk_lbl_destroy(ui->lbl_presets);
   
+  robtk_select_destroy(ui->sel_presets);
   robtk_select_destroy(ui->sel_oct_mode);
   robtk_select_destroy(ui->sel_oct_low);
   robtk_select_destroy(ui->sel_oct_high);
@@ -1661,6 +1769,9 @@ port_event(LV2UI_Handle handle,
           case TEMPO:
                   robtk_spin_set_value(ui->spb_tempo, (int)fValue);
           break;
+          case TEMPO_MODE:
+                  robtk_cbtn_set_active(ui->btn_tempo_mode, (fValue > 0));
+          break;
           default:
           break;
         }
