@@ -3,7 +3,7 @@
  * @brief Implementation of the RobTk-based LV2 GUI for the QMidiArp Seq plugin.
  *
  *
- *      Copyright 2009 - 2025 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2026 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      The structure as well as some lines of code and functions were 
  *      taken from sisco lv2 by Robin Garaeus: https://github.com/x42/sisco.lv2 
@@ -246,7 +246,19 @@ static bool update_range_in1 (RobWidget *widget, void* data)
 static bool update_transport (RobWidget *widget, void* data)
 {
     QMidiArpLfoUI* ui = (QMidiArpLfoUI*) data;
-    updateParam(ui, TRANSPORT_MODE, robtk_cbtn_get_active(ui->btn_transport));
+    bool act = robtk_cbtn_get_active(ui->btn_transport);
+    if (act) {
+      robtk_cbtn_set_active(ui->btn_tempo_mode, true);
+    }
+    robtk_cbtn_set_sensitive(ui->btn_tempo_mode, !act);
+    updateParam(ui, TRANSPORT_MODE, act);
+    return TRUE;
+}
+
+static bool update_tempo_mode (RobWidget *widget, void* data)
+{
+    QMidiArpLfoUI* ui = (QMidiArpLfoUI*) data;
+    updateParam(ui, TEMPO_MODE, robtk_cbtn_get_active(ui->btn_tempo_mode));
     return TRUE;
 }
 
@@ -490,6 +502,29 @@ static RobWidget* mouse_move(RobWidget* handle, RobTkBtnEvent *ev) {
   return handle;
 }
 
+static RobWidget* mouse_scroll(RobWidget* handle, RobTkBtnEvent *ev) {
+
+  QMidiArpLfoUI* ui = (QMidiArpLfoUI*) GET_HANDLE(handle);
+
+  int val = (int)robtk_dial_get_value(ui->dial_control[1]);
+
+  switch (ev->direction) {
+      case ROBTK_SCROLL_RIGHT:
+      case ROBTK_SCROLL_UP:
+        val += 2;
+        break;
+      case ROBTK_SCROLL_LEFT:
+      case ROBTK_SCROLL_DOWN:
+        val -= 2;
+        break;
+      default:
+        break;
+  }
+  robtk_dial_set_value(ui->dial_control[1], val);
+
+  return handle;
+}
+
 /******************************************************************************
  * Pango / Cairo Rendering, Expose
  */
@@ -732,6 +767,7 @@ static bool expose_event(RobWidget* handle, cairo_t* cr, cairo_rectangle_t *ev)
               1, color_txt3);
     }
     cairo_restore(cr);
+    ui->wave_drawn = true;
   }
   expose_cursor(handle, cr);
   ui->draw_only_cursor = false;
@@ -940,13 +976,20 @@ static void in_out_box_new(QMidiArpLfoUI* ui)
 
 // Transport controls
 
-  // Host / Internal transport
+  // Internal / Host transport
   ui->btn_transport = robtk_cbtn_new("Host transport", GBT_LED_LEFT, false);
   robtk_cbtn_set_color_on(ui->btn_transport, .7, .5, .2);
   robtk_cbtn_set_color_off(ui->btn_transport, .1, .1, .3);
   robtk_cbtn_set_callback(ui->btn_transport, update_transport, ui);
+  
+  // Internal / Host tempo
+  ui->btn_tempo_mode = robtk_cbtn_new("Tempo from host", GBT_LED_LEFT, false);
+  robtk_cbtn_set_color_on(ui->btn_tempo_mode, .2, .8, .5);
+  robtk_cbtn_set_color_off(ui->btn_tempo_mode, .1, .1, .3);
+  robtk_cbtn_set_callback(ui->btn_tempo_mode, update_tempo_mode, ui);
 
-  robtk_cbtn_set_active(ui->btn_transport, true);
+  robtk_cbtn_set_active(ui->btn_tempo_mode, true);
+  robtk_cbtn_set_active(ui->btn_transport, false);
   
   ui->lbl_tempo = robtk_lbl_new("Tempo");
   ui->spb_tempo = robtk_spin_new(5, 200, 1);
@@ -1004,6 +1047,8 @@ static void in_out_box_new(QMidiArpLfoUI* ui)
   // Transport
   TBLADD(robtk_cbtn_widget(ui->btn_transport), 0, 2, row, row+1);
   row++;
+  TBLADD(robtk_cbtn_widget(ui->btn_tempo_mode), 0, 2, row, row+1);
+  row++;
   TBLADD(robtk_lbl_widget(ui->lbl_tempo), 0, 1, row, row+1);
   TBLADD(robtk_spin_widget(ui->spb_tempo), 1, 2, row, row+1);
   row++;
@@ -1032,6 +1077,7 @@ static RobWidget * toplevel(QMidiArpLfoUI* ui, void * const top)
   robwidget_set_mousedown(ui->darea, mouse_down);
   robwidget_set_mousemove(ui->darea, mouse_move);
   robwidget_set_mouseup  (ui->darea, mouse_up);
+  robwidget_set_mousescroll  (ui->darea, mouse_scroll);
 
 // Add in_out box
   in_out_box_new(ui);
@@ -1299,6 +1345,7 @@ instantiate(
   ui->uiIsUp = false;
   ui->offset_suppress_callback = false;
   ui->draw_only_cursor = false;
+  ui->wave_drawn = false;
 
 
   for (int i = 0; features[i]; ++i) {
@@ -1398,6 +1445,7 @@ in_out_box_destroy(QMidiArpLfoUI *ui)
   robtk_lbl_destroy(ui->lbl_ch_out);
 
   robtk_cbtn_destroy(ui->btn_transport);
+  robtk_cbtn_destroy(ui->btn_tempo_mode);
   robtk_spin_destroy(ui->spb_tempo);
   robtk_lbl_destroy(ui->lbl_tempo);
 
@@ -1559,7 +1607,7 @@ port_event(LV2UI_Handle handle,
           case CURSOR_POS:
                   if (ui->currentIndex != (int)fValue) {
                     ui->currentIndex = (int)fValue;
-                    if (ui->mouse_pressed == 0) ui->draw_only_cursor = true;
+                    if (ui->mouse_pressed == 0 && ui->wave_drawn) ui->draw_only_cursor = true;
                     queue_draw_area(ui->darea, 0, LFOSCR_MIN_H - LFOSCR_VMARG + CSR_VMARG, DAWIDTH, 
                                         CSR_MIN_H);
                   }
@@ -1611,6 +1659,9 @@ port_event(LV2UI_Handle handle,
           case TEMPO:
                   robtk_spin_set_value(ui->spb_tempo, (int)fValue);
           break;
+          case TEMPO_MODE:
+                  robtk_cbtn_set_active(ui->btn_tempo_mode, (fValue > 0));
+          break;
           default:
           break;
         }
