@@ -3,7 +3,7 @@
  * @brief Headers for the RobTk-based LV2 GUI for the QMidiArp Lfo plugin.
  *
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2026 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      The structure as well as some lines of code and functions were 
  *      taken from sisco lv2 by Robin Garaeus: https://github.com/x42/sisco.lv2 
@@ -81,7 +81,8 @@ enum PortIndex {
             WaveOut = 32,
             HOST_TEMPO = 33,
             HOST_POSITION = 34,
-            HOST_SPEED = 35
+            HOST_SPEED = 35,
+            TEMPO_MODE = 36
         };
 
 #define RTK_URI QMIDIARP_LFO_LV2_URI "#"
@@ -144,6 +145,7 @@ typedef struct {
   bool isMuted;
   
   bool draw_only_cursor;
+  bool wave_drawn;
 
 // these two replace the Sample vectors (sequence or lfo wave)
 // ! when datavalue is negative the point is muted ! 
@@ -166,7 +168,7 @@ typedef struct {
   RobTkCBtn *btn_mute, *btn_restartkbd, *btn_triglegato, *btn_trigkbd;
   RobTkCBtn *btn_noteoff;
 
-  RobTkCBtn *btn_transport;
+  RobTkCBtn *btn_transport, *btn_tempo_mode;;
   RobTkLbl  *lbl_tempo;
   RobTkSpin *spb_tempo;
   RobWidget *hbox, *ctable_spin;
