@@ -3,7 +3,7 @@
  * @brief Implementation of the RobTk-based LV2 GUI for the QMidiArp Seq plugin.
  *
  *
- *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2026 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      The structure as well as some lines of code and functions were 
  *      taken from sisco lv2 by Robin Garaeus: https://github.com/x42/sisco.lv2 
@@ -127,7 +127,7 @@ static void ui_enable(LV2UI_Handle handle)
 
 void updateParam(LV2UI_Handle handle, int index, float fValue)
 {
-    QMidiArpSeqUI* ui = (QMidiArpSeqUI*)handle;    
+    QMidiArpSeqUI* ui = (QMidiArpSeqUI*)handle;
     ui->write(ui->controller, index, sizeof(float), 0, &fValue);
 }
 
@@ -221,7 +221,19 @@ static bool update_range_in1 (RobWidget *widget, void* data)
 static bool update_transport (RobWidget *widget, void* data)
 {
     QMidiArpSeqUI* ui = (QMidiArpSeqUI*) data;
-    updateParam(ui, TRANSPORT_MODE, robtk_cbtn_get_active(ui->btn_transport));
+    bool act = robtk_cbtn_get_active(ui->btn_transport);
+    if (act) {
+      robtk_cbtn_set_active(ui->btn_tempo_mode, true);
+    }
+    robtk_cbtn_set_sensitive(ui->btn_tempo_mode, !act);
+    updateParam(ui, TRANSPORT_MODE, act);
+    return TRUE;
+}
+
+static bool update_tempo_mode (RobWidget *widget, void* data)
+{
+    QMidiArpSeqUI* ui = (QMidiArpSeqUI*) data;
+    updateParam(ui, TEMPO_MODE, robtk_cbtn_get_active(ui->btn_tempo_mode));
     return TRUE;
 }
 
@@ -773,7 +785,8 @@ static bool expose_event(RobWidget* handle, cairo_t* cr, cairo_rectangle_t *ev)
       cairo_line_to(cr, xpos, ypos + 2);
       cairo_stroke(cr);
     }
-  cairo_restore(cr);
+    cairo_restore(cr);
+    ui->wave_drawn = true;
   }
   expose_cursor(handle, cr);
   ui->draw_only_cursor = false;
@@ -956,16 +969,23 @@ static void in_out_box_new(QMidiArpSeqUI* ui)
     
   robtk_select_set_item(ui->ch_out, 0);
   robtk_select_set_default_item(ui->ch_out, 0);
-  robtk_select_set_callback(ui->ch_in, update_ch_out, ui);
+  robtk_select_set_callback(ui->ch_out, update_ch_out, ui);
 
 // Transport controls
 
-  // Host / Internal transport
+  // Internal / Host transport
   ui->btn_transport = robtk_cbtn_new("Host transport", GBT_LED_LEFT, false);
   robtk_cbtn_set_color_on(ui->btn_transport, .2, .3, .9);
   robtk_cbtn_set_color_off(ui->btn_transport, .1, .1, .3);
   robtk_cbtn_set_callback(ui->btn_transport, update_transport, ui);
+  
+  // Internal / Host tempo
+  ui->btn_tempo_mode = robtk_cbtn_new("Tempo from host", GBT_LED_LEFT, false);
+  robtk_cbtn_set_color_on(ui->btn_tempo_mode, .2, .8, .5);
+  robtk_cbtn_set_color_off(ui->btn_tempo_mode, .1, .1, .3);
+  robtk_cbtn_set_callback(ui->btn_tempo_mode, update_tempo_mode, ui);
 
+  robtk_cbtn_set_active(ui->btn_tempo_mode, true);
   robtk_cbtn_set_active(ui->btn_transport, true);
   
   ui->lbl_tempo = robtk_lbl_new("Tempo");
@@ -1022,6 +1042,8 @@ static void in_out_box_new(QMidiArpSeqUI* ui)
   // Transport
   TBLADD(robtk_cbtn_widget(ui->btn_transport), 0, 2, row, row+1);
   row++;
+  TBLADD(robtk_cbtn_widget(ui->btn_tempo_mode), 0, 2, row, row+1);
+  row++;
   TBLADD(robtk_lbl_widget(ui->lbl_tempo), 0, 1, row, row+1);
   TBLADD(robtk_spin_widget(ui->spb_tempo), 1, 2, row, row+1);
   row++;
@@ -1293,6 +1315,7 @@ instantiate(
 
   ui->uiIsUp = false;
   ui->draw_only_cursor = false;
+  ui->wave_drawn = false;
 
 
   for (int i = 0; features[i]; ++i) {
@@ -1395,6 +1418,7 @@ in_out_box_destroy(QMidiArpSeqUI *ui)
   robtk_lbl_destroy(ui->lbl_ch_in);
   robtk_lbl_destroy(ui->lbl_ch_out);
 
+  robtk_cbtn_destroy(ui->btn_tempo_mode);
   robtk_cbtn_destroy(ui->btn_transport);
   robtk_spin_destroy(ui->spb_tempo);
   robtk_lbl_destroy(ui->lbl_tempo);
@@ -1543,7 +1567,7 @@ port_event(LV2UI_Handle handle,
           case CURSOR_POS:
                   if (ui->currentIndex != (int)fValue) {
                     ui->currentIndex = (int)fValue;
-                    if (ui->mouse_pressed == 0) ui->draw_only_cursor = true;
+                    if (ui->mouse_pressed == 0 && ui->wave_drawn) ui->draw_only_cursor = true;
                     queue_draw_area(ui->darea, 0, SEQSCR_MIN_H, DAWIDTH, 
                                         CSR_MIN_H + CSR_VMARG);
                   }
@@ -1617,6 +1641,9 @@ port_event(LV2UI_Handle handle,
           case TEMPO:
                   robtk_spin_set_value(ui->spb_tempo, (int)fValue);
           break;
+          case TEMPO_MODE:
+                  robtk_cbtn_set_active(ui->btn_tempo_mode, (fValue > 0));
+          break;
           default:
           break;
         }
