@@ -160,6 +160,14 @@ tohoto souboru, prosím, prostě spusťte qmidiarp.</translation>
         <source>Sync to Transport from Host</source>
         <translation></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GlobStore</name>
@@ -323,6 +331,14 @@ Kolečko myši: změna posunu</translation>
         <source>Sync to Transport from Host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogWidget</name>
@@ -1023,5 +1039,13 @@ zavoláním qmidiarp -a</translation>
         <source>Sync to Transport from Host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
