@@ -160,6 +160,14 @@ cuando todas las notas han sido reproducidas</translation>
         <source>Sync to Transport from Host</source>
         <translation></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GlobStore</name>
@@ -323,6 +331,14 @@ Rueda para cambiar desplazamiento</translation>
         <source>Sync to Transport from Host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogWidget</name>
@@ -1019,5 +1035,13 @@ Alternativamente usted puede utilizar el motor ALSA MIDI mediante la orden qmidi
         <source>Sync to Transport from Host</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Tempo from Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Let Host set tempo</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
